@@ -111,8 +111,8 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
         cpu_probe: ProcessProbe = self.probes['cpu']
         total_energy = 0
         net_transaction_time = 0
-        temperature_sensor = TemperatureSensor('data/temperature.txt')
-        humidity_sensor = HumiditySensor('data/humidity.txt')
+        temperature_sensor = TemperatureSensor('data/temperature_data.txt')
+        humidity_sensor = HumiditySensor('data/humidity_data.txt')
 
         while self.step(self.basic_time_step) != -1:
             # Blink lights
